@@ -16,6 +16,12 @@ operation_parameter_map = {
             {
                 'name': 'endDate'
             },
+            {
+                'name': 'offset'
+            },
+            {
+                'name': 'limit'
+            },
             {
                 'name': 'type'
             },
